@@ -346,6 +346,12 @@ def common_options(required):
     ]
 
     options = [
+        option(
+            "--no-cache",
+            default=False,
+            is_flag=True,
+            help="Build without using any compilation cache",
+        ),
         option(
             "--image-sha",
             default=None,
@@ -515,6 +521,7 @@ def build(
     download=False,
     output_dir=None,
     no_wait=False,
+    no_cache=False,
     patch_series=None,
     limit=LIMIT,
     json=False,
@@ -555,6 +562,7 @@ def build(
     if patch_series:
         build_params["patch_series"] = click.format_filename(patch_series)
 
+    build_params["no_cache"] = no_cache
     try:
         build = tuxsuite.Build(**build_params)
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
@@ -606,6 +614,7 @@ def build_set(
     output_dir=None,
     no_wait=False,
     patch_series=None,
+    no_cache=False,
     **build_params,
 ):
     quiet_output(quiet)
