@@ -95,20 +95,19 @@ def handle_list(options, config):
                 state_msg = (
                     f"{colors.state(test.state, test.result)}{state}{colors.reset}"
                 )
-                tests = ",".join(test.tests)
+                all_tests = ",".join(test.tests)
                 pt = test.provisioning_time
                 if pt is None:
                     pt = "....-..-..T..:..:........."
                 pt = pt[:-7]
                 print(
-                    f"{datediff(previous_pt, pt)} {test.uid} [{state_msg}] {tests}@{test.device} {test.kernel}"
+                    f"{datediff(previous_pt, pt)} {test.uid} [{state_msg}] {all_tests}@{test.device} {test.kernel}"
                 )
 
                 previous_pt = pt
             if sys.stdout.isatty():
                 # fetch next list of tests
                 tests, n_token = fetch_next(Test, config, url, n_token, options.limit)
-
     return 0
 
 
@@ -117,7 +116,6 @@ def handle_logs(options, config):
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/tests/{options.uid}/logs/lava",
     )
-    print(ret)
     if ret.status_code != 200:
         raise NotImplementedError()
 
@@ -179,8 +177,8 @@ def handle_submit(options, config):
     )
     if ret.status_code != 201:
         raise NotImplementedError
-
-    test = Test.new(ret.json())
+    data = ret.json()
+    test = Test.new(**data)
     if options.wait:
         options.uid = test.uid
         return handle_wait(options, config)
